try:
    from .reduce import (
        nansum,
        nanmean,
        nanstd,
        nanvar,
        nanmin,
        nanmax,
        median,
        nanmedian,
        ss,
        nanargmin,
        nanargmax,
        anynan,
        allnan,
    )
    from .nonreduce import replace
    from .nonreduce_axis import partition, argpartition, rankdata, nanrankdata, push
    from .move import (
        move_sum,
        move_mean,
        move_std,
        move_var,
        move_min,
        move_max,
        move_argmin,
        move_argmax,
        move_median,
        move_rank,
    )

    from . import slow

except ImportError:
    raise ImportError(
        "bottleneck modules failed to import, likely due to a "
        "mismatch in NumPy versions. Either upgrade numpy to "
        "1.16+ or install with:\n\t"
        "pip install --no-build-isolation --no-cache-dir "
        "bottleneck"
    )

from bottleneck.benchmark.bench import bench
from bottleneck.benchmark.bench_detailed import bench_detailed
from bottleneck.tests.util import get_functions

from ._pytesttester import PytestTester

test = PytestTester(__name__)
del PytestTester

from ._version import get_versions  # noqa: E402

__version__ = get_versions()["version"]
del get_versions



"""Check that functions can handle scalar input"""

from numpy.testing import assert_array_almost_equal
import bottleneck as bn
import pytest


@pytest.mark.parametrize(
    "func",
    bn.get_functions("reduce") + bn.get_functions("nonreduce_axis"),  # noqa: W504
    ids=lambda x: x.__name__,
)
def test_scalar_input(func, args=tuple()):
    """Test that bn.xxx gives the same output as bn.slow.xxx for scalar input."""
    if func.__name__ in ("partition", "argpartition", "push"):
        return
    func0 = eval("bn.slow.%s" % func.__name__)
    msg = "\nfunc %s | input %s\n"
    a = -9
    argsi = [a] + list(args)
    actual = func(*argsi)
    desired = func0(*argsi)
    err_msg = msg % (func.__name__, a)
    assert_array_almost_equal(actual, desired, err_msg=err_msg)
